ResolverConfig

Struct ResolverConfig 

pub struct ResolverConfig { /* private fields */ }
Available on crate features memberlist-net and dns only.
Configuration for the upstream nameservers to use for resolution

Implementations

Source

impl ResolverConfig

pub fn new() -> ResolverConfig

Available on crate feature agnostic only.

Creates a new empty configuration

pub fn google() -> ResolverConfig

Available on crate feature agnostic only.

Creates a default configuration, using 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844 (thank you, Google).

Please see Google’s privacy statement for important information about what they track, many ISP’s track similar information in DNS. To use the system configuration see: Resolver::from_system_conf.

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn google_tls() -> ResolverConfig

Available on crate features agnostic and __tls only.

Creates a default configuration, using 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844 (thank you, Google). This limits the registered connections to just TLS lookups

Please see Google’s privacy statement for important information about what they track, many ISP’s track similar information in DNS. To use the system configuration see: Resolver::from_system_conf.

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn google_https() -> ResolverConfig

Available on crate features agnostic and __https only.

Creates a default configuration, using 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844 (thank you, Google). This limits the registered connections to just HTTPS lookups

Please see Google’s privacy statement for important information about what they track, many ISP’s track similar information in DNS. To use the system configuration see: Resolver::from_system_conf.

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn google_h3() -> ResolverConfig

Available on crate features agnostic and __h3 only.

Creates a default configuration, using 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844 (thank you, Google). This limits the registered connections to just HTTP/3 lookups

Please see Google’s privacy statement for important information about what they track, many ISP’s track similar information in DNS. To use the system configuration see: Resolver::from_system_conf.

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn cloudflare() -> ResolverConfig

Available on crate feature agnostic only.

Creates a default configuration, using 1.1.1.1, 1.0.0.1 and 2606:4700:4700::1111, 2606:4700:4700::1001 (thank you, Cloudflare).

Please see: https://www.cloudflare.com/dns/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn cloudflare_tls() -> ResolverConfig

Available on crate features agnostic and __tls only.

Creates a configuration, using 1.1.1.1, 1.0.0.1 and 2606:4700:4700::1111, 2606:4700:4700::1001 (thank you, Cloudflare). This limits the registered connections to just TLS lookups

Please see: https://www.cloudflare.com/dns/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn cloudflare_https() -> ResolverConfig

Available on crate features agnostic and __https only.

Creates a configuration, using 1.1.1.1, 1.0.0.1 and 2606:4700:4700::1111, 2606:4700:4700::1001 (thank you, Cloudflare). This limits the registered connections to just HTTPS lookups

Please see: https://www.cloudflare.com/dns/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn quad9() -> ResolverConfig

Available on crate feature agnostic only.

Creates a configuration, using 9.9.9.9, 149.112.112.112 and 2620:fe::fe, 2620:fe::fe:9, the “secure” variants of the quad9 settings (thank you, Quad9).

Please see: https://www.quad9.net/faq/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn quad9_tls() -> ResolverConfig

Available on crate features agnostic and __tls only.

Creates a configuration, using 9.9.9.9, 149.112.112.112 and 2620:fe::fe, 2620:fe::fe:9, the “secure” variants of the quad9 settings. This limits the registered connections to just TLS lookups

Please see: https://www.quad9.net/faq/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn quad9_https() -> ResolverConfig

Available on crate features agnostic and __https only.

Creates a configuration, using 9.9.9.9, 149.112.112.112 and 2620:fe::fe, 2620:fe::fe:9, the “secure” variants of the quad9 settings. This limits the registered connections to just HTTPS lookups

Please see: https://www.quad9.net/faq/

NameServerConfigGroups can be combined to use a set of different providers, see NameServerConfigGroup and ResolverConfig::from_parts

pub fn from_parts<G>( domain: Option<Name>, search: Vec<Name>, name_servers: G, ) -> ResolverConfig

Available on crate feature agnostic only.

Create a ResolverConfig with all parts specified

Arguments
  • domain - domain of the entity querying results. If the Name being looked up is not an FQDN, then this is the first part appended to attempt a lookup. ndots in the ResolverOption does take precedence over this.
  • search - additional search domains that are attempted if the Name is not found in domain, defaults to vec![]
  • name_servers - set of name servers to use for lookups, defaults are Google: 8.8.8.8, 8.8.4.4 and 2001:4860:4860::8888, 2001:4860:4860::8844
pub fn domain(&self) -> Option<&Name>

Available on crate feature agnostic only.

Returns the local domain

By default any names will be appended to all non-fully-qualified-domain names, and searched for after any ndots rules

pub fn set_domain(&mut self, domain: Name)

Available on crate feature agnostic only.

Set the domain of the entity querying results.

pub fn search(&self) -> &[Name]

Available on crate feature agnostic only.

Returns the search domains

These will be queried after any local domain and then in the order of the set of search domains

Available on crate feature agnostic only.

Add a search domain

pub fn add_name_server(&mut self, name_server: NameServerConfig)

Available on crate feature agnostic only.

Add the configuration for a name server

pub fn name_servers(&self) -> &[NameServerConfig]

Available on crate feature agnostic only.

Returns a reference to the name servers