SignatureScheme

Enum SignatureScheme 

#[non_exhaustive]
pub enum SignatureScheme {
Show 17 variants RSA_PKCS1_SHA1, ECDSA_SHA1_Legacy, RSA_PKCS1_SHA256, ECDSA_NISTP256_SHA256, RSA_PKCS1_SHA384, ECDSA_NISTP384_SHA384, RSA_PKCS1_SHA512, ECDSA_NISTP521_SHA512, RSA_PSS_SHA256, RSA_PSS_SHA384, RSA_PSS_SHA512, ED25519, ED448, ML_DSA_44, ML_DSA_65, ML_DSA_87, Unknown(u16),
}
Available on crate features memberlist-net and tls only.
The SignatureScheme TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA. The Unknown item is used when processing unrecognised ordinals.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


RSA_PKCS1_SHA1



ECDSA_SHA1_Legacy



RSA_PKCS1_SHA256



ECDSA_NISTP256_SHA256



RSA_PKCS1_SHA384



ECDSA_NISTP384_SHA384



RSA_PKCS1_SHA512



ECDSA_NISTP521_SHA512



RSA_PSS_SHA256



RSA_PSS_SHA384



RSA_PSS_SHA512



ED25519



ED448



ML_DSA_44



ML_DSA_65



ML_DSA_87



Unknown(u16)

Implementations

Source

impl SignatureScheme

pub fn to_array(self) -> [u8; 2]

pub fn as_str(&self) -> Option<&'static str>