pub struct CompressHint { /* private fields */ }Available on crate features
zstd or lz4 or brotli or snappy only.Expand description
The hint of how the payload is compressed in the buffer.
Implementations
Sourceimpl CompressHint
impl CompressHint
Sourcepub const fn header_offset(&self) -> usize
pub const fn header_offset(&self) -> usize
Returns the start offset of the header.
Sourcepub const fn payload_offset(&self) -> usize
pub const fn payload_offset(&self) -> usize
Returns the payload offset.
Sourcepub const fn max_output_size(&self) -> usize
pub const fn max_output_size(&self) -> usize
Returns the maximum output size of the compressed payload.