pub struct NodeId<const N: usize = nodecraft::::id::impls::id::NodeId::{constant#0}>(/* private fields */);Available on crate feature
memberlist-quic only.Expand description
A unique string identifying a server for all time. The maximum length of an id is 512 bytes.
Implementations
Sourceimpl<const N: usize> NodeId<N>
impl<const N: usize> NodeId<N>
Sourcepub const MAX_SIZE: usize = N
Available on crate feature memberlist-net only.
pub const MAX_SIZE: usize = N
memberlist-net only.The maximum length of an id is N bytes.
Sourcepub fn new<T>(src: T) -> Result<NodeId<N>, ParseNodeIdError>
Available on crate feature memberlist-net only.
pub fn new<T>(src: T) -> Result<NodeId<N>, ParseNodeIdError>
memberlist-net only.Creates a new Id from the source.
Sourcepub fn as_str(&self) -> &str
Available on crate feature memberlist-net only.
pub fn as_str(&self) -> &str
memberlist-net only.converts the Id into a &str.
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
Available on crate feature memberlist-net only.
pub fn as_bytes(&self) -> &[u8] ⓘ
memberlist-net only.Returns a byte slice.
To convert the byte slice back into a string slice, use the core::str::from_utf8 function.