pub struct InsufficientSpace { /* private fields */ }Expand description
An error that occurs when trying to write data to a buffer with insufficient space.
This error indicates that a write operation failed because the buffer does not have enough remaining capacity to hold the data.
Implementations
Sourceimpl InsufficientSpace
impl InsufficientSpace
Sourcepub const fn new(
requested: NonZero<usize>,
available: usize,
) -> InsufficientSpace
pub const fn new( requested: NonZero<usize>, available: usize, ) -> InsufficientSpace
Creates a new InsufficientSpace error with the requested and available bytes.
Panics
Panics if requested is not greater than available.